@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2023 Univention GmbH
+# Copyright 2004-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -46,7 +46,7 @@ try:
     from types import TracebackType  # noqa: F401
     from typing import Any, Callable, List, Optional, Type, TypeVar, Union  # noqa: F401
 
-    _F = TypeVar("_F", bound=Callable[..., Any])
+    _F = TypeVar("_F", bound=Callable[..., Any])  # noqa: PYI018
 except ImportError:
     pass
 
